@@ -3,9 +3,10 @@ from .functions import pvalues_plot
 from .functions import chi_square
 from .functions import F_test
 from .functions import rsquares_iter
-from .functions import randomforest
+from .functions import quick_rf_importance
 from .functions import permutation_importance
 from .functions import woe_iv
+from .functions import barchart_dict
 
 
 __all__ = [
